@@ -24,7 +24,9 @@ pub mod brew;
 mod cargo;
 mod git;
 pub mod hash;
+mod pkg;
 mod resource;
+pub mod scoop;
 pub mod workflow;
 
 #[cfg(test)] // <-- not needed in integration tests
